#ifndef OSLP_METHOD_H
#define OSLP_METHOD_H

#include <config.h>

#include <glib/gstrfuncs.h>
#include <glib.h>
#include <libgnomevfs/gnome-vfs-cancellable-ops.h>
#include <libgnomevfs/gnome-vfs-ops.h>
#include <libgnomevfs/gnome-vfs-i18n.h>
#include <libgnomevfs/gnome-vfs-module.h>
#include <slp.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define SLP_INITIAL_URI "slp"
#define SLP_INITIAL_URI_LENGTH 3


enum {
	SLP_SERVICES,		/*  Example : slp:/// */
	SLP_SERVICE_TYPE,	/* Example : slp:///ldap.novell */
	SLP_SERVER_NAME		/* Example : slp:///ldap.novell/164.99.152.151 */
} uri_type;


typedef struct {
	SLPHandle openslp_handle;	/* The OpenSlp Handle */
	GNode *root;			/* Root of the n-ary tree */
	GNode *cur_child;		/* Pointer to the current node */
	GNode *find_child;		/* Pointer to the child node 
					being searched for  */
	//  size_t file_size;
} Handle;

typedef struct {
	char *display_data;	/* URI to be displayed. */
	char *data;		/* For storing the SLP service URLs */
	gboolean is_dir;
} SlpHandle;





/* Module entry points. */
GnomeVFSMethod *vfs_module_init(const char *method_name, const char *args);
void vfs_module_shutdown(GnomeVFSMethod * method);





/* Utility functions implemented in oslp-util.c */

/* Custom made function for searching a node in the tree on "display_data"
search_data is derived from the URI */

GNode *my_g_node_find(GNode * root, const char *search_data);


/* Custom made function for freeing the dynamically allocated elements of "data" member of all the g_nodes. NOT BEING USED NOW.*/

void my_g_node_destroy(GNode * root);


gboolean is_directory(GnomeVFSURI * uri);

char *return_display_name(char *uri);

SlpHandle *give_tmp_slp_handle(const char *display_data, gboolean is_dir);

char *parse_and_extract(GnomeVFSURI * uri, int type);

int determine_uri_type(GnomeVFSURI * uri);

void parse_tree(GNode * handle);



#endif				/* OSLP_METHOD_H */
